<!--
SPDX-FileCopyrightText: 2026 Helge Eichhorn <git@helgeeichhorn.de>

SPDX-License-Identifier: MPL-2.0
-->

# lox-ephem

Ephemeris handling for the [Lox](https://github.com/lox-space/lox) ecosystem, including
SPK/SPICE kernel support.

Part of [Lox – Oxidized Astrodynamics](https://github.com/lox-space/lox).
